=================================
BO4E - Business Object for Energy
=================================

This is the official documentation of the **BO4E** data model.

Welcome to the BO4E (Business Object for Energy) data model!
This model is specifically designed with the German energy market in mind.

Our primary goal is to facilitate seamless information exchange between market partners.

The BO4E data model provides a standardized format for data communication, making it easier for different systems to interact and understand each other.
It's all about improving efficiency, reducing errors, and fostering a more collaborative energy market.

Whether you're a utility, a grid operator, a metering point operator, or a software service provider, the BO4E data model can help streamline your data exchange processes and enhance your collaborations in the energy market.

We invite you to explore the BO4E data model and discover how it can benefit your operations in the German energy market.


Membership
==========

Companies interested in contributing to the development and maintenance of this data model can become members of this registered non-profit association.
As a member, your company will have the opportunity to influence the development of the BO4E data model and contribute to the evolution of the German energy market.
For more information on how to become a member, please contact us.

Contents
========

.. toctree::
   :maxdepth: 2

   Fundamentals <fundamentals>
   Data Model Overview <api/modules>
   BusinessObjects <api/bo4e.bo>
   Components <api/bo4e.com>
   Enumerations <api/bo4e.enum>
   Versioning <versioning>
   Release Workflow <release_workflow>
   Contributing <contributing_guide>
   Changelog <changelog>
   Authors <authors>
   License <license>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _toctree: http://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html
.. _reStructuredText: http://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
.. _references: http://www.sphinx-doc.org/en/stable/markup/inline.html
.. _Python domain syntax: http://sphinx-doc.org/domains.html#the-python-domain
.. _Sphinx: http://www.sphinx-doc.org/
.. _Python: http://docs.python.org/
.. _Numpy: http://docs.scipy.org/doc/numpy
.. _SciPy: http://docs.scipy.org/doc/scipy/reference/
.. _matplotlib: https://matplotlib.org/contents.html#
.. _Pandas: http://pandas.pydata.org/pandas-docs/stable
.. _Scikit-Learn: http://scikit-learn.org/stable
.. _autodoc: http://www.sphinx-doc.org/en/stable/ext/autodoc.html
.. _Google style: https://github.com/google/styleguide/blob/gh-pages/pyguide.md#38-comments-and-docstrings
.. _NumPy style: https://numpydoc.readthedocs.io/en/latest/format.html
.. _classical style: http://www.sphinx-doc.org/en/stable/domains.html#info-field-lists
